Author: David Schneider <david.schnei...@picle.org>
Branch: buildbot-update
Changeset: r849:3781586166f4
Date: 2013-09-03 13:34 +0200
http://bitbucket.org/pypy/buildbot/changeset/3781586166f4/

Log:    keep trunk as meta-branch that groups default and builds without an
        explicit branch

diff --git a/bot2/pypybuildbot/test/test_summary.py 
b/bot2/pypybuildbot/test/test_summary.py
--- a/bot2/pypybuildbot/test/test_summary.py
+++ b/bot2/pypybuildbot/test/test_summary.py
@@ -482,7 +482,7 @@
     builder.nextBuildNumber = n
 
 
-METABRANCH = '<default>'
+METABRANCH = '<trunk>'
 
 
 class TestSummary(object):
diff --git a/master/templates/layout.html b/master/templates/layout.html
--- a/master/templates/layout.html
+++ b/master/templates/layout.html
@@ -26,7 +26,7 @@
         -
         <!-- PyPy specific items -->
         <a href="http://speed.pypy.org/";>Speed</a>
-        <a href="{{ path_to_root }}summary?branch=&lt;default&gt;">Summary 
(default)</a>
+        <a href="{{ path_to_root }}summary?branch=&lt;trunk&gt;">Summary 
(trunk)</a>
         <a href="{{ path_to_root }}summary">Summary</a>
         <a href="{{ path_to_root }}nightly/">Nightly builds</a>
         <!-- end of PyPy specific items -->
_______________________________________________
pypy-commit mailing list
pypy-commit@python.org
https://mail.python.org/mailman/listinfo/pypy-commit

Reply via email to
diff --git a/bot2/pypybuildbot/summary.py b/bot2/pypybuildbot/summary.py
--- a/bot2/pypybuildbot/summary.py
+++ b/bot2/pypybuildbot/summary.py
@@ -624,10 +624,10 @@
     return subst
 
 # Map certain branch names from SourceStamps to a common name shown on the page
-meta_branch_name = make_subst(['default', '', None], '<default>')
-# map the meta-branch <default> to the actual branch entries from the
+meta_branch_name = make_subst(['default', '', None], '<trunk>')
+# map the meta-branch <trunk> to the actual branch entries from the
 # SourceStamp
-default_value = make_subst('<default>', ['default', '', None])
+default_value = make_subst('<trunk>', ['default', '', None])
 category_name = make_subst(None, '-')
 nocat_value = make_subst("-", None)
 
@@ -876,8 +876,8 @@
             default_vs_any_text = "filter nothing"
             default_vs_any_query = ""
         else:
-            default_vs_any_text = "all <default>"
-            default_vs_any_query = "?branch=<default>"
+            default_vs_any_text = "all <trunk>"
+            default_vs_any_query = "?branch=<trunk>"
 
         default_vs_any_anchor = html.a(default_vs_any_text,
                                      href="/summary%s" %